@@ -122,7 +122,7 @@ PyObject *BackupToPython(GSM_Backup *backup) {
     } else {\
         len = PyList_Size(o);\
         if (len > maxlen) {\
-            pyg_warning("Too many entries in %s, truncating to %d from %d!\n", key, maxlen, len);\
+            pyg_warning("Too many entries in %s, truncating to %d from %" PY_FORMAT_SIZE_T "d!\n", key, maxlen, len);\
             len = maxlen;\
         }\
         for (i = 0; i < len; i++) {\
@@ -139,8 +139,8 @@ PyObject *BackupToPython(GSM_Backup *backup) {
 int BackupFromPython(PyObject *dict, GSM_Backup *backup) {
     PyObject            *o;
     PyObject            *x;
-    int                 len;
-    int                 i;
+    Py_ssize_t          len;
+    Py_ssize_t          i;
     char                *s;
 
     if (!PyDict_Check(dict)) {
