@@ -332,8 +332,8 @@ PyObject *CalendarToPython(const GSM_CalendarEntry *entry) {
 int CalendarFromPython(PyObject *dict, GSM_CalendarEntry *entry, int needs_location) {
     PyObject        *o;
     PyObject        *item;
-    int             len;
-    int             i;
+    Py_ssize_t      len;
+    Py_ssize_t      i;
     char            *t;
     char            *type;
     char            valuetype;
@@ -377,7 +377,7 @@ int CalendarFromPython(PyObject *dict, GSM_CalendarEntry *entry, int needs_locat
         item = PyList_GetItem(o, i);
         if (item == NULL) return 0;
         if (!PyDict_Check(item)) {
-            PyErr_Format(PyExc_ValueError, "Element %i in Values is not dictionary", i);
+            PyErr_Format(PyExc_ValueError, "Element %" PY_FORMAT_SIZE_T "d in Values is not dictionary", i);
             return 0;
         }
         type = GetCharFromDict(item, "Type");
@@ -450,7 +450,7 @@ int CalendarFromPython(PyObject *dict, GSM_CalendarEntry *entry, int needs_locat
             entry->Entries[i].EntryType = CAL_REPEAT_DAYOFYEAR;
 
         } else {
-            PyErr_Format(PyExc_ValueError, "Element %i in Values has bad type: %s", i, type);
+            PyErr_Format(PyExc_ValueError, "Element %" PY_FORMAT_SIZE_T "d in Values has bad type: %s", i, type);
             return 0;
         }
 
