@@ -147,7 +147,11 @@ PyObject *MemoryEntryToPython(const GSM_MemoryEntry *entry) {
                 convert_text("Text_JobTitle");
                 break;
             case PBK_Category:
-                f = Py_BuildValue("{s:s,s:i}", "Type", "Category", "Value", entry->Entries[i].Number);
+                if (entry->Entries[i].Number == -1) {
+                    convert_text("Category");
+                } else {
+                    f = Py_BuildValue("{s:s,s:i}", "Type", "Category", "Value", entry->Entries[i].Number);
+                }
                 break;
             case PBK_Private:
                 f = Py_BuildValue("{s:s,s:i}", "Type", "Private", "Value", entry->Entries[i].Number);
@@ -212,6 +216,9 @@ PyObject *MemoryEntryToPython(const GSM_MemoryEntry *entry) {
             case PBK_CallLength:
                 f = Py_BuildValue("{s:s,s:i}", "Type", "CallLength", "Value", entry->Entries[i].CallLength);
                 break;
+            case PBK_Number_Messaging:
+                convert_number("Messaging");
+                break;
             case PBK_PushToTalkID:
                 convert_text("PushToTalkID");
                 break;
@@ -257,8 +264,8 @@ PyObject *MemoryEntryToPython(const GSM_MemoryEntry *entry) {
 int MemoryEntryFromPython(PyObject *dict, GSM_MemoryEntry *entry, int needs_location) {
     PyObject        *o;
     PyObject        *item;
-    int             len;
-    int             i;
+    Py_ssize_t      len;
+    Py_ssize_t      i;
     char            *type;
     char            valuetype;
 
@@ -299,7 +306,7 @@ int MemoryEntryFromPython(PyObject *dict, GSM_MemoryEntry *entry, int needs_loca
         item = PyList_GetItem(o, i);
         if (item == NULL) return 0;
         if (!PyDict_Check(item)) {
-            PyErr_Format(PyExc_ValueError, "Element %i in Entries is not dictionary", i);
+            PyErr_Format(PyExc_ValueError, "Element %" PY_FORMAT_SIZE_T "d in Entries is not dictionary", i);
             return 0;
         }
         type = GetCharFromDict(item, "Type");
@@ -346,6 +353,9 @@ int MemoryEntryFromPython(PyObject *dict, GSM_MemoryEntry *entry, int needs_loca
         } else if (strcmp("Number_Other", type) == 0) {
             valuetype = 't';
             entry->Entries[i].EntryType = PBK_Number_Other;
+        } else if (strcmp("Number_Messaging", type) == 0) {
+            valuetype = 't';
+            entry->Entries[i].EntryType = PBK_Number_Messaging;
         } else if (strcmp("Text_Note", type) == 0) {
             valuetype = 't';
             entry->Entries[i].EntryType = PBK_Text_Note;
@@ -395,7 +405,7 @@ int MemoryEntryFromPython(PyObject *dict, GSM_MemoryEntry *entry, int needs_loca
             valuetype = 't';
             entry->Entries[i].EntryType = PBK_Text_JobTitle;
         } else if (strcmp("Category", type) == 0) {
-            valuetype = 'n';
+            valuetype = 'o';
             entry->Entries[i].EntryType = PBK_Category;
         } else if (strcmp("Private", type) == 0) {
             valuetype = 'n';
@@ -464,11 +474,19 @@ int MemoryEntryFromPython(PyObject *dict, GSM_MemoryEntry *entry, int needs_loca
             valuetype = 't';
             entry->Entries[i].EntryType = PBK_PushToTalkID;
         } else {
-            PyErr_Format(PyExc_ValueError, "Element %i in Entries has bad type: %s", i, type);
+            PyErr_Format(PyExc_ValueError, "Element %" PY_FORMAT_SIZE_T "d in Entries has bad type: %s", i, type);
             return 0;
         }
 
         switch (valuetype) {
+            case 'o':
+                entry->Entries[i].Number = GetIntFromDict(item, "Value");
+                if (entry->Entries[i].Number == INT_INVALID) {
+                    PyErr_Clear();
+                    if (!CopyStringFromDict(item, "Value", GSM_PHONEBOOK_TEXT_LENGTH, entry->Entries[i].Text))
+                        return 0;
+                }
+                break;
             case 'n':
                 entry->Entries[i].Number = GetIntFromDict(item, "Value");
                 if (entry->Entries[i].Number == INT_INVALID) return 0;
