@@ -34,47 +34,31 @@ GSM_CategoryType StringToCategoryType(const char *s) {
 }
 
 GSM_MemoryType StringToMemoryType(const char *s) {
-    if (strcmp(s, "ME") == 0)      return MEM_ME;
-    else if (strcmp(s, "SM") == 0) return MEM_SM;
-    else if (strcmp(s, "ON") == 0) return MEM_ON;
-    else if (strcmp(s, "DC") == 0) return MEM_DC;
-    else if (strcmp(s, "RC") == 0) return MEM_RC;
-    else if (strcmp(s, "MC") == 0) return MEM_MC;
-    else if (strcmp(s, "MT") == 0) return MEM_MT;
-    else if (strcmp(s, "FD") == 0) return MEM_FD;
-    else if (strcmp(s, "VM") == 0) return MEM_VM;
-    else if (strcmp(s, "SL") == 0) return MEM_SL;
-    else {
+    GSM_MemoryType type;
+
+    type = GSM_StringToMemoryType(s);
+
+    if (type == 0) {
         PyErr_Format(PyExc_ValueError, "Bad value for memory type: '%s'", s);
-        return 0;
     }
+
+    return type;
 }
 
 char *MemoryTypeToString(GSM_MemoryType t) {
     char *s;
 
-    s = malloc(3);
+    s = strdup(GSM_MemoryTypeToString(t));
     if (s == NULL) {
         PyErr_SetString(PyExc_MemoryError, "Not enough memory to allocate string");
         return NULL;
     }
-    s[0] = 0;
-    s[2] = 0;
-    switch (t) {
-        case MEM_ME: s[0] = 'M'; s[1] = 'E'; return s;
-        case MEM_SM: s[0] = 'S'; s[1] = 'M'; return s;
-        case MEM_ON: s[0] = 'O'; s[1] = 'N'; return s;
-        case MEM_DC: s[0] = 'D'; s[1] = 'C'; return s;
-        case MEM_RC: s[0] = 'R'; s[1] = 'C'; return s;
-        case MEM_MC: s[0] = 'M'; s[1] = 'C'; return s;
-        case MEM_MT: s[0] = 'M'; s[1] = 'T'; return s;
-        case MEM_FD: s[0] = 'F'; s[1] = 'D'; return s;
-        case MEM_VM: s[0] = 'V'; s[1] = 'M'; return s;
-        case MEM_SL: s[0] = 'S'; s[1] = 'L'; return s;
+    if (strcmp("XX", s) == 0) {
+        PyErr_Format(PyExc_ValueError, "Bad value for MemoryType from Gammu: '%02x'", t);
+        free(s);
+        s = NULL;
     }
-    PyErr_Format(PyExc_ValueError, "Bad value for MemoryType from Gammu: '%02x'", t);
-    free(s);
-    return NULL;
+    return s;
 }
 
 
