@@ -456,7 +456,7 @@ GSM_Coding_Type StringToSMSCoding(const char *s) {
 
 char *SMSCodingToString(GSM_Coding_Type type) {
     char *err = "Err";
-    char *s = NULL;
+    char *s = err;
 
     switch (type) {
         case SMS_Coding_Unicode_No_Compression:
@@ -992,8 +992,8 @@ PyObject *MultiSMSToPython(GSM_MultiSMSMessage *sms) {
 
 int MultiSMSFromPython(PyObject *list, GSM_MultiSMSMessage *sms) {
     PyObject    *item;
-    int         len;
-    int         i;
+    Py_ssize_t  len;
+    Py_ssize_t  i;
 
     if (!PyList_Check(list)) {
         PyErr_Format(PyExc_ValueError, "Multi SMS is not a list");
@@ -1003,7 +1003,7 @@ int MultiSMSFromPython(PyObject *list, GSM_MultiSMSMessage *sms) {
     len = PyList_Size(list);
 
     if (len > GSM_MAX_MULTI_SMS) {
-        pyg_warning("Truncating MultiSMS entries to %d entries! (from %d))\n", GSM_MAX_MULTI_SMS, len);
+        pyg_warning("Truncating MultiSMS entries to %d entries! (from %" PY_FORMAT_SIZE_T "d))\n", GSM_MAX_MULTI_SMS, len);
         len = GSM_MAX_MULTI_SMS;
     }
     sms->Number = len;
@@ -1012,7 +1012,7 @@ int MultiSMSFromPython(PyObject *list, GSM_MultiSMSMessage *sms) {
         item = PyList_GetItem(list, i);
         if (item == NULL) return 0;
         if (!PyDict_Check(item)) {
-            PyErr_Format(PyExc_ValueError, "Element %i in Messages is not dictionary", i);
+            PyErr_Format(PyExc_ValueError, "Element %" PY_FORMAT_SIZE_T "d in Messages is not dictionary", i);
             return 0;
         }
         if (!SMSFromPython(item, &(sms->SMS[i]), 0, 0, 0)) return 0;
@@ -1023,8 +1023,8 @@ int MultiSMSFromPython(PyObject *list, GSM_MultiSMSMessage *sms) {
 
 int MultiSMSListFromPython(PyObject *list, GSM_MultiSMSMessage ***sms) {
     PyObject    *item;
-    int         len;
-    int         i;
+    Py_ssize_t  len;
+    Py_ssize_t  i;
     int         j;
 
     if (!PyList_Check(list)) {
@@ -1048,7 +1048,7 @@ int MultiSMSListFromPython(PyObject *list, GSM_MultiSMSMessage ***sms) {
             return 0;
         }
         if (!PyList_Check(item)) {
-            PyErr_Format(PyExc_ValueError, "Element %i in Messages is not list", i);
+            PyErr_Format(PyExc_ValueError, "Element %" PY_FORMAT_SIZE_T "d in Messages is not list", i);
             for (j = 0; j < i; j++) free((*sms)[j]);
             free((*sms));
             return 0;
@@ -1730,8 +1730,8 @@ int SMSPartFromPython(PyObject *dict, GSM_MultiPartSMSEntry *entry) {
 int SMSInfoFromPython(PyObject *dict, GSM_MultiPartSMSInfo *entry) {
     PyObject        *o;
     PyObject        *item;
-    int             len;
-    int             i;
+    Py_ssize_t      len;
+    Py_ssize_t      i;
 
     if (!PyDict_Check(dict)) {
         PyErr_Format(PyExc_ValueError, "SMS info is not a dictionary");
@@ -1782,7 +1782,7 @@ int SMSInfoFromPython(PyObject *dict, GSM_MultiPartSMSInfo *entry) {
     len = PyList_Size(o);
 
     if (len > GSM_MAX_MULTI_SMS - 1) {
-        pyg_warning("Too many entries, truncating from %d to %d\n", len, GSM_MAX_MULTI_SMS - 1);
+        pyg_warning("Too many entries, truncating from %" PY_FORMAT_SIZE_T "d to %d\n", len, GSM_MAX_MULTI_SMS - 1);
         len = GSM_MAX_MULTI_SMS - 1;
     }
 
@@ -1795,7 +1795,7 @@ int SMSInfoFromPython(PyObject *dict, GSM_MultiPartSMSInfo *entry) {
             return 0;
         }
         if (!PyDict_Check(item)) {
-            PyErr_Format(PyExc_ValueError, "Element %i in Entries is not dictionary", i);
+            PyErr_Format(PyExc_ValueError, "Element %" PY_FORMAT_SIZE_T "d in Entries is not dictionary", i);
             return 0;
         }
 
@@ -1886,8 +1886,8 @@ PyObject *SMSBackupToPython(GSM_SMS_Backup *sms) {
 
 int SMSBackupFromPython(PyObject *list, GSM_SMS_Backup *sms) {
     PyObject    *item;
-    int         len;
-    int         i;
+    Py_ssize_t  len;
+    Py_ssize_t  i;
 
     if (!PyList_Check(list)) {
         PyErr_Format(PyExc_ValueError, "SMS Backup is not a list");
@@ -1907,7 +1907,7 @@ int SMSBackupFromPython(PyObject *list, GSM_SMS_Backup *sms) {
             return 0;
         }
         if (!PyDict_Check(item)) {
-            PyErr_Format(PyExc_ValueError, "Element %i in SMS Backup is not dict", i);
+            PyErr_Format(PyExc_ValueError, "Element %" PY_FORMAT_SIZE_T "d in SMS Backup is not dict", i);
             return 0;
         }
 
