@@ -97,13 +97,13 @@ Py_UNICODE *strGammuToPythonL(const unsigned char *src, const int len) {
 }
 
 PyObject *UnicodeStringToPython(const unsigned char *src) {
-    int         len;
+    Py_ssize_t  len;
 
     len = UnicodeLength(src);
     return UnicodeStringToPythonL(src, len);
 }
 
-PyObject *UnicodeStringToPythonL(const unsigned char *src, const int len) {
+PyObject *UnicodeStringToPythonL(const unsigned char *src, const Py_ssize_t len) {
     Py_UNICODE  *val;
     PyObject    *res;
 
